package com.caimei365.commodity.service.impl;

import com.caimei365.commodity.components.PriceUtilService;
import com.caimei365.commodity.mapper.MallProductMapper;
import com.caimei365.commodity.mapper.PageMapper;
import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.dto.Sku;
import com.caimei365.commodity.model.vo.MallOrganizeProductVo;
import com.caimei365.commodity.model.vo.MallProductSkuVo;
import com.caimei365.commodity.model.vo.PaginationVo;
import com.caimei365.commodity.model.vo.ProductDetailVo;
import com.caimei365.commodity.service.MallProductService;
import com.github.pagehelper.PageHelper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2023/5/11
 */
@Service
public class MallProductServiceImpl implements MallProductService {

    @Autowired private MallProductMapper productMapper;
    @Autowired private PriceUtilService priceUtilService;


    /**
     * 商品列表
     *
     * @param productName
     * @return
     */
    @Override
    public ResponseJson<PaginationVo<MallOrganizeProductVo>> productList(String productName, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        // 商品信息
        List<MallOrganizeProductVo> productList = productMapper.productList(productName);
        if (null != productList) {
            // 商品sku
            productList.forEach(product -> {
                if (null != product.getProductId()) {
                    List<Sku> mallSkus = productMapper.getMallSkus(product.getProductId());
                    if (null != mallSkus) {
                        mallSkus.forEach(s -> {
                            s.setPriceGrade(priceUtilService.getPriceGrade(s.getPrice()));
                        });
                        product.setSku(mallSkus);
                    }
                }
            });
        }
        PaginationVo<MallOrganizeProductVo> page = new PaginationVo<>(productList);
        return ResponseJson.success(page);
    }

    /**
     * 外部商城商品详情
     * @param productId
     * @return
     */
    @Override
    public ResponseJson<Map<String, Object>> productInfo(Integer productId) {
        Map<String, Object> map = new HashMap<>();
        // 商品信息
        MallOrganizeProductVo product = productMapper.getOrganizeProductDetails(productId);
        if (null != product) {
            // 商品sku
            if (null != product.getProductId()) {
                List<Sku> mallSkus = productMapper.getMallSkus(product.getProductId());
                if (null != mallSkus) {
                    mallSkus.forEach(s -> {
                        s.setPriceGrade(priceUtilService.getPriceGrade(s.getPrice()));
                    });
                    product.setSku(mallSkus);
                }
            }
        }
        map.put("product", product);
        return ResponseJson.success(map);
    }
}
